<?php
/**
 * Déclarations relatives à la base de données
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Base
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Déclaration des alias de tables et filtres automatiques de champs
 *
 * @pipeline declarer_tables_interfaces
 * @param array $interfaces
 *     Déclarations d'interface pour le compilateur
 * @return array
 *     Déclarations d'interface pour le compilateur
 */
function subdivisions_declarer_tables_interfaces($interfaces) {

	$interfaces['table_des_tables']['subdivisions'] = 'subdivisions';

	$interfaces['table_des_traitements']['NOM_USAGE']['subdivisions'] = _TRAITEMENT_TYPO;
	$interfaces['table_des_traitements']['ISO_TITRE']['subdivisions'] = _TRAITEMENT_TYPO;
		
 	return $interfaces;
}


/**
 * Déclaration des objets éditoriaux
 *
 * @pipeline declarer_tables_objets_sql
 * @param array $tables
 *     Description des tables
 * @return array
 *     Description complétée des tables
 */
function subdivisions_declarer_tables_objets_sql($tables) {

	$tables['spip_subdivisions'] = array(
		'texte_retour' => 'icone_retour',
		'texte_objets' => 'subdivision:titre_subdivisions',
		'texte_objet' => 'subdivision:titre_subdivision',
		'texte_modifier' => 'subdivision:icone_modifier_subdivision',
		'texte_creer' => 'subdivision:icone_creer_subdivision',
		'info_aucun_objet'=> 'subdivision:info_aucune_subdivision',
		'info_1_objet' => 'subdivision:info_1_subdivision',
		'info_nb_objets' => 'subdivision:info_nb_subdivisions',
		'texte_logo_objet' => 'subdivision:titre_logo_subdivision',
		'texte_langue_objet' => 'subdivision:titre_langue_subdivision',
		'type' => 'subdivision',
		'principale' => 'oui',
		'field'=> array(
			'id_subdivision'	=> 'bigint(21) NOT NULL',
			'iso_subdivision' => "varchar(6) DEFAULT '' NOT NULL", // code ISO 3166-2 de l'objet
			'categorie' => "varchar(255) DEFAULT '' NOT NULL", // type de l'objet (au sens ISO)
			'iso_parent' => "varchar(6) DEFAULT '' NOT NULL", // code ISO 3166-2 du parent de la subdivision
			'iso_pays' => "char(2) DEFAULT '' NOT NULL",   // code  ISO 3166 alpha2 du pays de la subdivision
			'iso_titre' => 'text NOT NULL', // nom donné par la norme iso (format multi)
			'nom_usage' => 'text NOT NULL', // nom d'usage ou commercial (format multi)
			'date' => "datetime DEFAULT '0000-00-00 00:00:00' NOT NULL", // date de mise en ligne
			'statut' => "varchar(255) DEFAULT '0' NOT NULL", // permet la mise à la poubelle (archivage)
			'maj' => "TIMESTAMP NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP"
		),
		'key' => array(
			'PRIMARY KEY' => 'id_subdivision',
			"KEY iso_subdivision" => "iso_subdivision",
			"KEY iso_parent" => "iso_parent",
			"KEY iso_pays" => "iso_pays"
		),
		'titre' => 'nom_usage AS titre, "" AS lang',
		'date' => "date",
		'champs_editables'  => array('nom_usage'),
		'champs_versionnes' => array('nom_usage'),
		'rechercher_champs' => array("titre" => 10, 'nom_usage' => 10, "iso_moi" => 10, 'iso_pays' => 5, 'iso_parent' => 5),
		'tables_jointures' => array( 'subdivisions_liens' ),
		'statut'=> array(
			array(
				'champ' => 'statut',
				'publie' => 'publie',
				'previsu' => 'publie',
				'post_date' => 'date',
				'exception' => array('statut','tout')
			)
		),
		'statut_textes_instituer' => array(
			'publie' => 'texte_statut_publie',
			'poubelle' => 'texte_statut_poubelle'
		),
		'texte_changer_statut' => 'subdivision:texte_changer_statut'		
	);


 return $tables;

}

/**
 * Déclaration des tables auxiliaires
 *
 * @pipeline declarer_tables_objets_sql
 * @param array $tables
 * 		Description des tables
 *			spip_subdivisions_liens. Table de liaisons. Référence des association des subdivisions aux objets.
 *			spip_subdivisions_schemas. Table des schémas. Version des données installées, par pays.
 *
 * @return array
 *     Description complétée des tables
 */

function subdivisions_declarer_tables_auxiliaires($tables) {

	$tables['spip_subdivisions_liens'] = array(
		'field' => array(
			"id_subdivision" => "bigint(21) NOT NULL DEFAULT '0'",
			"id_objet" => "bigint(21) DEFAULT '0' NOT NULL",
			"objet" => "VARCHAR(25) DEFAULT '' NOT NULL",
			"role" => "varchar(30) NOT NULL DEFAULT ''"
		),
		'key' => array(
			"PRIMARY KEY" => "id_subdivision,id_objet,objet,role",
			"KEY id_subdivision" => "id_subdivision",
			"KEY id_objet" => "id_objet",
			"KEY objet" => "objet",
			"KEY role" => "role"
		)
	);

	$tables['spip_subdivisions_schemas'] = array(
		'field' => array(
			"iso_pays" => "CHAR(2) default '' NOT NULL",   // code  ISO 3166 alpha2 du pays installé
			"isocode_schema" => "VARCHAR(24) default '' NOT NULL", // schéma plugin isocode qui a apporté les données
			"maj" => "TIMESTAMP NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP" // mise-à-jour
		),
		'key' => array(
			"PRIMARY KEY" => "iso_pays",
			"KEY isocode_schema" => "isocode_schema"
		)
	);

	return $tables;
}
