<?php

/**
 * Fonction pour charger les données disponibles pour un peuplement 
 *
 * Cette fonction relative à la base de donnée est distincte de l'API de Subdivisions.
 * L'API est une interface entre les données et l'utilisateur, qui permet de manipuler (traiter) les opérations.
 * La présente fonction (charger) est du côté de la donnée et offre les données à l'API.
 * Elle est surchargeable pour permettre de changer les modalités de la mise à disposition des données.
 *
 * @plugin Subdivisions
 *
 **/

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Fonction surchargeable chargeant les données.
 *
 * @param void|string|array $arg
 *     $arg = "FR" demande d'un pays par son identifiant ISO3166-1 Alpha 2
 *
 * @return 
 */
 
function base_subdivisions_charger_dist ($arg = '') {

	// Vérifications

	$regex = '/^([A-Z]{2})$/';
	if (!preg_match($regex, $arg)) { // demande non conforme
		return _T('subdivision:verifier_pays_demande_non_conforme');
	}
	$conditions = array("country=" . sql_quote($arg));
		
	// on charge les informations de Nomenclatures Officielles
	
	// tant que l’API RESt n’est pas disponible sur un serveur de la communauté 
	// on appelle directement l’API PHP en faisant :

	include_spip('ezrest/isocode');
	$subs = subdivisions_collectionner($conditions, $filtres, $configuration);			
	$schema_isocode = $GLOBALS['meta']['isocode_base_version'];

	return array ($schema_isocode, $subs);		
	
}
