<?php
/**
 * Fichier gérant l'installation et désinstallation du plugin Subdivisions Géographiques
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2019-2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Installation
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Fonction d'installation et de mise à jour du plugin Subdivisions Géographiques.
 *
 * @param string $nom_meta_base_version
 *     Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 * @param string $version_cible
 *     Version du schéma de données dans ce plugin (déclaré dans paquet.xml)
 * @return void
**/
function subdivisions_upgrade($nom_meta_base_version, $version_cible) {
	$maj = array();

	$maj['create'] = array(
		array('maj_tables', array('spip_subdivisions', 'spip_subdivisions_liens', 'spip_subdivisions_schemas')),
 	);

 	include_spip('base/upgrade');
	maj_plugin($nom_meta_base_version, $version_cible, $maj);

}


/**
 * Fonction de désinstallation du plugin Subdivisions Géographiques.
 *
 * @param string $nom_meta_base_version
 *     Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 * @return void
**/
function subdivisions_vider_tables($nom_meta_base_version) {

	# Suppression des tables
	sql_drop_table('spip_subdivisions');
	sql_drop_table('spip_subdivisions_liens');
	sql_drop_table('spip_subdivisions_schemas');

	# Nettoyer les versionnages
	sql_delete('spip_versions', sql_in('objet', array('subdivision')));
	sql_delete('spip_versions_fragments', sql_in('objet', array('subdivision')));

	effacer_meta($nom_meta_base_version);
}
