<?php
/**
 * Définit les autorisations du plugin Subdivisions Géographiques
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Autorisations
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Fonction d'appel pour le pipeline
 * @pipeline autoriser */
function subdivisions_autoriser() {
}

/**
 * Autorisation de voir un élément de menu (subdivisions)
 *
 * Fonction relative aux menus déroulant de l'interface privée
 *
 * @param  string $faire Action demandée
 * @param  string $type  Type d'objet sur lequel appliquer l'action
 * @param  int    $id    Identifiant de l'objet
 * @param  array  $qui   Description de l'auteur demandant l'autorisation
 * @param  array  $opt   Options de cette autorisation
 * @return bool          true s'il a le droit, false sinon
**/

function autoriser_subdivisions_menu_dist($faire, $type, $id, $qui, $opt) {
	// l'admin peut tout
	if ($qui['statut'] == '0minirezo') return true;

	// pour les autres cas, on se fie à la déclaration de la constante
	$statut = AUTEURS_MIN_REDAC; // ceux qui peuvent écrire
	$statut = str_replace(',5poubelle', '', $statut); // on retire 5poubelle
	$statut = explode(',', $statut);

	return in_array($qui['statut'], $statut);
}

/**
 * Autorisation de créer une subdivision
 *
 * @param  string $faire Action demandée
 * @param  string $type  Type d'objet sur lequel appliquer l'action
 * @param  int    $id    Identifiant de l'objet
 * @param  array  $qui   Description de l'auteur demandant l'autorisation
 * @param  array  $opt   Options de cette autorisation
 * @return bool          true s'il a le droit, false sinon
**/

function autoriser_subdivision_creer_dist($faire, $type, $id, $qui, $opt) {

	// la création d'une subdivision se fait par peuplement 

		return false;
}

/**
 * Autorisation de modifier une subdivision
 *
 * Cette modification se limite à la modification du nom d'usage
 *
 * @param  string $faire Action demandée
 * @param  string $type  Type d'objet sur lequel appliquer l'action
 * @param  int    $id    Identifiant de l'objet
 * @param  array  $qui   Description de l'auteur demandant l'autorisation
 * @param  array  $opt   Options de cette autorisation
 * @return bool          true s'il a le droit, false sinon
**/

function autoriser_subdivision_modifier_dist($faire, $type, $id, $qui, $opt) {

	// l'admin peut tout
	if ($qui['statut'] == '0minirezo') return true;

	// pour les autres cas, on se fie à la déclaration de la constante
	$statut = AUTEURS_MIN_REDAC; // ceux qui peuvent écrire
	$statut = str_replace(',5poubelle', '', $statut); // on retire 5poubelle
	$statut = explode(',', $statut);

	return in_array($qui['statut'], $statut);
}

